import matplotlib
import numpy as np
import matplotlib.pyplot as plt
from apm import *

server = 'http://xps.apmonitor.com'

app = 'nlp'
apm(server,app,'clear all')
apm_load(server,app,app + '.apm')
apm_option(server,app,'nlc.solver',3)
solver_output = apm(server,app,'solve')
print solver_output
url = apm_web_var(server,app)

## Generate a contour plot
x = np.arange(1.0, 4.52, 0.02)
y = np.arange(1.0, 4.52, 0.02)
x1, x2 = np.meshgrid(x, y)

# objective function:
obj = x2 * (5.0 + x1)

# constraint1: 
c1 = x1 * x2

# constraint 2:
# x1^2 + x2^2 <= 20
c2 = np.power(x1,2) + \
     np.power(x2,2)

n = 5
mu = np.logspace(2,-2,n)

for i in range(0,n):
    # barrier problem
    psi = obj - mu[i] * np.log(c1-5.0) - mu[i] * np.log(20.0-c2)

    # create contour plot
    plt.figure()
    #plt.set_size_inches(3.5,2.5)
    plt.title('Contour Plot with log10(mu) = ' + str(float(int(10.0*np.log10(mu[i])))/10.0))
    lines = [10,15,20,25,30,35]
    CS = plt.contour(x1,x2,obj,lines)
    plt.clabel(CS,inline=1,fontsize=10)

    # add x and y plot labels
    plt.xlabel('x1')
    plt.ylabel('x2')

    # constraint #1
    CS = plt.contour(x1,x2,c1, \
    	[5.0,5.2], \
	colors='r', \
	linewidths=[4.0,1.0])
    plt.clabel(CS, inline=1, fontsize=10)

    # constraint #2
    CS = plt.contour(x1,x2,c2,[19.5,20.0], \
	colors='b', \
	linewidths=[1.0,4.0])
    plt.clabel(CS,inline=1,fontsize=10)

    # barrier problem
    psi_min = np.floor(np.nanmin(psi))
    lines = np.linspace(psi_min,30,10)
    CS = plt.contour(x1,x2,psi,lines)
    plt.clabel(CS,inline=1,fontsize=10)

    # save figures
    if i<=9:
        plt.savefig('contour0' + str(i) + '.png')
    else:
        plt.savefig('contour' + str(i) + '.png')
    
# show figures
#plt.show()
